@@ -167,7 +167,7 @@ class Foreperson:
             self.data_source.origin.id = recipe['visit']['visit id']
             if 'date' in recipe['visit'].keys():
                 self.data_source.origin.date = datetime.datetime.strptime(str(recipe['visit']['date']), '%Y-%m-%d')
-                self.data_source.origin.year = self.data_state.origin.date.year()
+                self.data_source.origin.year = self.data_source.origin.date.year()
             if 'local contact' in recipe['visit'].keys():
                 self.data_source = recipe['visit']['local contact']
             if 'user' in recipe['visit'].keys():
